{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">Do Majors = Jobs?</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/do_majors_equal_jobs_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/do_majors_equal_jobs_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/do_majors_equal_jobs_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/do_majors_equal_jobs_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/do_majors_equal_jobs_650.jpg' %}"
                     alt="Two engineering students studying together at a whiteboard.">
            
            
                <p class="myuw-image-credit">Photo: Dennis Wise</p>
            
        </figure>
        <div class="myuw-article-body">
        <p>While some technical fields may be exceptions to this, <a href="http://www.naceweb.org/career-development/trends-and-predictions/job-outlook-2016-attributes-employers-want-to-see-on-new-college-graduates-resumes/" target="_blank" >most employers value attributes</a> like leadership, written and verbal communication, and the ability to solve complex problems over an individual's undergraduate major. This can help relieve the pressure of feeling locked into something for the rest of your life and allow you to approach your major as a way of building these sought after skills which lead to work experience.</p>

<p>But you still have to figure out what you might want to do, right? There are lots of ways to <a href="https://www.washington.edu/uaa/advising/academic-planning/majors-and-minors/majors-and-careers/" target="_blank">explore career options</a> including asking yourself questions for reflection (what kind of work could you be immersed in?) and doing some research (what are your options?). Friends and family know you best and might also have ideas for what would be a good fit for you. Plus there are experts here at UW &#8211; academic advisers and career counselors &#8211; who can help you identify effective strategies for figuring out what you want to do.</p> 

<p>Ultimately, most people have a lot of flexibility for taking their major, combined with their other experiences, and shaping their career trajectory.</p>
        </div>
        
            <h3 class="myuw-heading-page">Resources</h3>
            <ul>
                
                    <li><a href="https://careers.uw.edu/blog/2017/08/02/what-if-my-major-doesnt-match-my-career-plans/">What If My Major Doesn’t Match My Career Plans?</a></li>
                
                    <li><a href="https://www.collegexpress.com/articles-and-advice/majors-and-academics/articles/choosing-major/truth-about-college-majors/">The Truth About College Majors</a></li>
                
            </ul>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience?article=wheres-your-focuslearning-or-competing">Where&#39;s Your Focus – Learning or Competing?</a></li>
                
                    <li><a href="/husky_experience?article=falling-love-class">Falling in Love with a Class</a></li>
                
                    <li><a href="/husky_experience?article=got-experience">Got Experience?</a></li>
                
                    <li><a href="/husky_experience?article=are-you-your-gpa">Are you your GPA?</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
